<?php
/*
Plugin Name: Entuberate
Description: Entuberate
Donate Link: https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=92XWZSS88YF9C
Version: 1.0
Author: Kenneth Rapp <kennethrapp1@gmail.com>
License: GPLv2 or later
*/

class Entuberate{

	private $plugin_name;
	private $cache_dir;

	function __construct()
	{
		$this->plugin_name = plugin_basename(__FILE__);
		$this->cache_dir = realpath(dirname(__FILE__).DIRECTORY_SEPARATOR."cache");
		
		add_shortcode('wp_entuberate_account',  array($this, 'shortcode_account'));
		add_shortcode('wp_entuberate_playlist', array($this, 'shortcode_playlist'));
		add_shortcode('wp_entuberate_id',       array($this, 'shortcode_id'));
		
		wp_enqueue_style( 'wp_entuberate_css', plugin_dir_url(__FILE__). 'wpyoutubeapi.css' );
		wp_enqueue_script('wp_entuberate_js',  plugin_dir_url(__FILE__) . 'wpyoutubeapi.js', array( 'jquery'), 1, true );
		
	}
	
	// [yt_id id=NNNNNNNNN]
	function shortcode_id($atts, $content)
	{
		$options = shortcode_atts(array(
			"id"     => "JIEUN01cyYg",
			"cache"  => 120
		), $atts);
		
		return $this->DisplayPlayer($options["id"], $options['cache']);	
	}
	
	// [yt_account user=NNNNNNNNN]
	function shortcode_account($atts, $content)
	{
		$json = null;
		$options = shortcode_atts(array("user" => "Google", "cache" => 120, "thumbsize"=>1, "paginate" => -1), $atts);
		$apiurl = "users/".$options['user']."/uploads";
		
		if($json = $this->GetData($apiurl, $options['cache']))
		{
			return $this->DisplayPlaylist($json, $options['thumbsize']);
		}
		
		return "";
	}
	
	// [yt_playlist list=NNNNNNNN]
	function shortcode_playlist($atts, $content)
	{
		$json = null;
		$options = shortcode_atts(array("list" => "PL70DEC2B0568B5469", "cache" => 120, "thumbsize"=>1), $atts);
		$apiurl = "playlists/".$options['list'];
		
		if($json = $this->GetData($apiurl, $options['cache']))
		{
			return $this->DisplayPlaylist($json, $options['thumbsize']);
		}
		
		return "";
		
	}
	
	private function GetData($apiurl, $cache)
	{	
		$path = $this->cache_dir."\\".md5($apiurl).".json";
		
		$cached = realpath($path);
		
		$time=time();
		
		if($cached && is_readable($cached))
		{
			$json = json_decode(file_get_contents($cached), true);

			if(($time-filemtime($cached)) >= $cache)
			{
				unlink($cached);
			}
			
			$this->Esc($json);
			return $json;
		}
		else
		{
			$ch = curl_init();
			
			curl_setopt($ch, CURLOPT_URL, "http://gdata.youtube.com/feeds/api/".$apiurl."?v=2&alt=json"); 
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);  

			$data = curl_exec($ch); 
			
			curl_close($ch); 
			
			$json = json_decode($data, true);
	
			file_put_contents($path, $data);

			$this->Esc($json);
			return $json;
			
		}
		
		return "";
		
	}
	
	private function Esc(&$array)
	{
		foreach($array as $key=>$val)
		{
			if(is_array($val))
			{
				$this->Esc($array[$key]);		
			}
			else $array[$key] = htmlspecialchars($val, ENT_QUOTES);
		}
	}

	private function DisplayPlaylist($json, $thumbsize = 0)
	{
		ob_start();
		
		?>
		
			
			<header>
			<h4>
				<?php $mediaItem = $json['feed']['media$group'];  
					
					foreach($json['feed']['link'] as $link)
					{
						if($link['type'] == "text/html")
						{
						?>
							<a href="<?php echo $link['href']; ?>">
								<?php echo $json['feed']['title']['$t']; ?> 
							</a> 
						<?php
							break;
						}
					}
				?>
			</h4>
			
			by 
			
			<a href="//www.youtube.com/user/<?php 
				$username = array_pop(explode("/", $json['feed']['author'][0]['uri']['$t']));
				echo $username; 
			?>"> 
			
			<?php echo $json['feed']['author'][0]['name']['$t']; ?> </a> 

			</header>
			
				[ <a href="<?php echo $json['feed']['link'][0]['href']; ?>">alternate</a> 
				| <a href="<?php echo $json['feed']['link'][1]['href']; ?>">rss</a> ]
		<?php 
		
			foreach($json['feed']['entry'] as $key=>$feedItem)
			{
				echo $this->DisplayYoutubePreview($feedItem, $thumbsize);
			}
			
		?> 
		
		<?php
		
		$content = ob_get_contents();
		$buffer = preg_replace(array("/\r/", "/\n/","/\s{2,}/"), array("", "", " "), $content);
		ob_end_clean();
		return $buffer;
	}

	private function DisplayPlayer($id, $cache=120)
	{
		ob_start();
		
		$apiurl = "videos/$id";
		
		if($data = $this->GetData($apiurl,$cache))
		{
			?>
			<div class="ytfeeditem"> 
				<div class="ytplaylistheader"> 
					
					<h4><a href="<?php 
					
						foreach($data['entry']['link'] as $link)
						{
							if($link['type'] == "text/html")
							{
								echo $link['href'];
								break; 
							}
						}
					?>">
					<?php echo $data['entry']['title']['$t']; ?></a></h4>
					by <a href="//www.youtube.com/user/<?php echo $data['entry']['author'][0]['name']['$t']; ?>">
					<?php echo $data['entry']['author'][0]['name']['$t']; ?>
					</a>
				</div>
				
				<div class="ytplayer"> 
					<iframe id  = "ytplayer" 
						  type  = "text/html" 
						   src  = "//www.youtube.com/embed/<?php echo $id; ?>" 
					frameborder = 0 > </iframe> 
				</div> 
				
				<?php echo $data['entry']['media$group']['media$description']['$t']; ?>
				
			</div>
			<?php 
		}
		
		$content = ob_get_contents();
		$buffer = preg_replace(array("/\r/", "/\n/","/\s{2,}/"), array("", "", " "), $content);
		ob_end_clean();
		return $buffer;
	}
	
	private function DisplayYoutubePreview(&$item, $thumbsize=0)
	{
		ob_start();
		
		$mediaItem = $item['media$group'];
		
		?> 
		<div class="ytfeeditem"> 
			<?php if($thumbsize >= 0) { ?> 
				<span class="ytfeedthumbnail" data-embed-src="<?php echo $item['content']['src']; ?>" > 
					
					<img src="<?php echo plugin_dir_url(__FILE__); ?>play.png" class="ytplayicon"> 
					
					<img   src = "<?php echo $mediaItem['media$thumbnail'][$thumbsize]['url'];    ?>" 
						 width = "<?php echo $mediaItem['media$thumbnail'][$thumbsize]['width'];  ?>" 
						height = "<?php echo $mediaItem['media$thumbnail'][$thumbsize]['height']; ?>" 
						border = 0 
					> 
				</span>	 
			<?php } ?> 
			
			<span class="ytfeedheader"> 
				<a href="<?php echo $item['link'][0]['href']; ?>"> 
					<?php echo $item['title']['$t']; ?> 
				</a>  
			</span>
		
			<?php if (isset($mediaItem['category'])){
			
				foreach($mediaItem['category'] as $key=>$mediaCategory)
				{
					if(array_key_exists('label', $mediaCategory))
					{
						?> 
						<span class="ytlabel">
							<?php echo $mediaCategory['label']['$t']; ?>
						</span>
						<?php
					}
				}
			} ?> 
			<div class="ytdescription">
				<?php echo $mediaItem['media$description']['$t']; ?> 
			</div> 
		</div> 
		<?php
		
		$content = ob_get_contents();
		$buffer = preg_replace(array("/\r/", "/\n/","/\s{2,}/"), array("", "", " "), $content);
		ob_end_clean();
		return $buffer;
	}
}


$WP_Entuberate = new Entuberate();